@@ -172,7 +172,6 @@ saveout.net <- function(dat, s, out = NULL) {
     out$control <- dat$control
     out$nwparam <- dat$nwparam
     out$num.nw <- dat$num.nw
-    out[["last_timestep"]] <- get_current_timestep(dat)
 
     out$coef.form <- list()
     out$coef.form[[s]] <- lapply(dat$nwparam, `[[`, "coef.form")
@@ -182,11 +181,15 @@ saveout.net <- function(dat, s, out = NULL) {
       out$epi[[names(dat$epi)[j]]] <- data.frame(dat$epi[j])
     }
 
-    out$el.cuml <- list()
-    out$el.cuml[[s]] <- dat$el.cuml
+    if (dat$control$save.run) {
+      out$run <- list()
+      out$run[[s]] <- dat$run
+    }
 
-    out[["_last_unique_id"]] <- list()
-    out[["_last_unique_id"]][[s]] <- dat[["_last_unique_id"]]
+    if (dat$control$save.cumulative.edgelist) {
+      out$cumulative.edgelist <- list()
+      out$cumulative.edgelist[[s]] <- get_cumulative_edgelists_df(dat)
+    }
 
     out$attr.history <- list()
     out$attr.history[[s]] <- dat$attr.history
@@ -223,22 +226,28 @@ saveout.net <- function(dat, s, out = NULL) {
     if (!is.null(dat$control$save.other)) {
       for (i in seq_along(dat$control$save.other)) {
         el.name <- dat$control$save.other[i]
-        out[[el.name]] <- list(dat[[el.name]])
+        if (el.name %in% names(dat)) {
+          out[[el.name]][[s]] <- dat[[el.name]]
+        } else if (el.name %in% names(dat$run)) {
+          out[[el.name]][[s]] <- dat$run[[el.name]]
+        } else {
+          warning("`", el.name, "` is not saved in `dat` or `dat$run`")
+        }
       }
     }
 
     if (dat$control$save.diss.stats == TRUE &&
-        dat$control$save.network == TRUE &&
-        dat$control$tergmLite == FALSE &&
-        !is.null(dat$nwparam)) {
+          dat$control$save.network == TRUE &&
+          dat$control$tergmLite == FALSE &&
+          !is.null(dat$nwparam)) {
 
       ## for each simulated network, if dissolution model is edges-only, compute diss stats
       out$diss.stats <- list(lapply(seq_len(dat$num.nw), function(network) {
         if (dat$nwparam[[network]]$coef.diss$diss.model.type == "edgesonly") {
-          toggles_to_diss_stats(tedgelist_to_toggles(as.data.frame(dat$nw[[network]])),
+          toggles_to_diss_stats(tedgelist_to_toggles(as.data.frame(dat$run$nw[[network]])),
                                 dat$nwparam[[network]]$coef.diss,
                                 dat$control$nsteps,
-                                dat$nw[[network]])
+                                dat$run$nw[[network]])
         } else {
           NULL
         }
@@ -276,9 +285,13 @@ saveout.net <- function(dat, s, out = NULL) {
       out$epi[[names(dat$epi)[j]]][, s] <- data.frame(dat$epi[j])
     }
 
-    out$el.cuml[[s]] <- dat$el.cuml
+    if (dat$control$save.run) {
+      out$run[[s]] <- dat$run
+    }
 
-    out[["_last_unique_id"]][[s]] <- dat[["_last_unique_id"]]
+    if (dat$control$save.cumulative.edgelist) {
+      out$cumulative.edgelist[[s]] <- get_cumulative_edgelists_df(dat)
+    }
 
     out$attr.history[[s]] <- dat$attr.history
     out$raw.records[[s]] <- dat$raw.records
@@ -310,22 +323,28 @@ saveout.net <- function(dat, s, out = NULL) {
     if (!is.null(dat$control$save.other)) {
       for (i in seq_along(dat$control$save.other)) {
         el.name <- dat$control$save.other[i]
-        out[[el.name]][[s]] <- dat[[el.name]]
+        if (el.name %in% names(dat)) {
+          out[[el.name]][[s]] <- dat[[el.name]]
+        } else if (el.name %in% names(dat$run)) {
+          out[[el.name]][[s]] <- dat$run[[el.name]]
+        } else {
+          warning("`", el.name, "` is not saved in `dat` or `dat$run`")
+        }
       }
     }
 
     if (dat$control$save.diss.stats == TRUE &&
-        dat$control$save.network == TRUE &&
-        dat$control$tergmLite == FALSE &&
-        !is.null(dat$nwparam)) {
+          dat$control$save.network == TRUE &&
+          dat$control$tergmLite == FALSE &&
+          !is.null(dat$nwparam)) {
 
       ## for each simulated network, if dissolution model is edges-only, compute diss stats
       out$diss.stats[[s]] <- lapply(seq_len(dat$num.nw), function(network) {
         if (dat$nwparam[[network]]$coef.diss$diss.model.type == "edgesonly") {
-          toggles_to_diss_stats(tedgelist_to_toggles(as.data.frame(dat$nw[[network]])),
+          toggles_to_diss_stats(tedgelist_to_toggles(as.data.frame(dat$run$nw[[network]])),
                                 dat$nwparam[[network]]$coef.diss,
                                 dat$control$nsteps,
-                                dat$nw[[network]])
+                                dat$run$nw[[network]])
         } else {
           NULL
         }
@@ -342,21 +361,31 @@ saveout.net <- function(dat, s, out = NULL) {
       colnames(out$epi[[i]]) <- simnames
     }
 
-    top_lvl_elts <- c("el.cuml", "_last_unique_id", "attr.history", ".records")
+    if (length(out$run) > 0) {
+      out$run <- name_saveout_elts(out$run, "run", simnames)
+    }
+
+    top_lvl_elts <- c("attr.history", ".records")
     for (elt in top_lvl_elts) {
       out[[elt]] <- name_saveout_elts(out[[elt]], elt, simnames)
     }
 
+    if (dat$control$save.cumulative.edgelist) {
+      out$cumulative.edgelist <- name_saveout_elts(
+        out$cumulative.edgelist, "cumulative.edgelist", simnames
+      )
+    }
+
     out$coef.form <- name_saveout_elts(out$coef.form, "coef.form", simnames)
 
     if (dat$control$save.nwstats == TRUE) {
-      out$stats$nwstats <- name_saveout_elts(
-        out$stats$nwstats, "stats$nwstats", simnames)
+      out$stats$nwstats <- name_saveout_elts(out$stats$nwstats,
+                                             "stats$nwstats", simnames)
     }
 
     if (dat$control$save.transmat == TRUE) {
-      out$stats$transmat <- name_saveout_elts(
-        out$stats$transmat, "stats$transmat", simnames)
+      out$stats$transmat <- name_saveout_elts(out$stats$transmat,
+                                              "stats$transmat", simnames)
     }
 
     if (dat$control$save.network == TRUE) {
@@ -364,13 +393,16 @@ saveout.net <- function(dat, s, out = NULL) {
     }
 
     if (dat$control$save.diss.stats == TRUE &&
-        dat$control$save.network == TRUE &&
-        dat$control$tergmLite == FALSE) {
+          dat$control$save.network == TRUE &&
+          dat$control$tergmLite == FALSE) {
       out$diss.stats <- name_saveout_elts(out$diss.stats, "diss.stats", simnames)
     }
 
+    # only rename top level elements, not the ones part of `run`
     for (el.name in dat$control$save.other) {
-      out[[el.name]] <- name_saveout_elts(out[[el.name]], el.name, simnames)
+      if (el.name %in% names(out)) {
+        out[[el.name]] <- name_saveout_elts(out[[el.name]], el.name, simnames)
+      }
     }
 
     # Remove functions from control list
@@ -407,8 +439,7 @@ saveout.net <- function(dat, s, out = NULL) {
 #'  \item \strong{stats:} a list containing two sublists, \code{nwstats} for any
 #'        network statistics saved in the simulation, and \code{transmat} for
 #'        the transmission matrix saved in the simulation. See
-#'        \code{\link{control.net}} and the
-#'        \href{http://www.epimodel.org/tut.html}{tutorials} for further
+#'        \code{\link{control.net}} for further
 #'        details.
 #'  \item \strong{network:} a list of \code{networkDynamic} objects,
 #'         one for each model simulation.
@@ -431,13 +462,14 @@ process_out.net <- function(dat_list) {
   return(out)
 }
 
+# Assign names to the save elements
+# Gives a warning if there aren't enough elements
 name_saveout_elts <- function(elt, elt_name, simnames) {
   if (length(elt) == length(simnames)) {
     names(elt) <- simnames
   } else if (length(elt) > 0) {
-    warning(
-      "The number of `", elt_name, "` is not the number of simulations.",
-      "Unable to assign each to the correct simulation.")
+    warning("The number of `", elt_name, "` is not the number of simulations.",
+            "Unable to assign each to the correct simulation.")
   }
   return(elt)
 }
