@@ -217,10 +217,17 @@ test_that("differing length non-nested update_dissolution tests", {
   expect_true(all(round(as.numeric(est_het$coef.form), 3) ==
                 round(as.numeric(est_het_compare$coef.form), 3)))
 
-  expect_equal(est_hom_compare$formation, ~edges + nodematch("race", diff = TRUE) +
-                 offset(edges))
-  expect_equal(est_het_compare$formation, ~edges + nodematch("race", diff = TRUE) +
-                 offset(edges) + offset(nodematch("age", diff = TRUE)))
+  expect_equal(est_hom_compare$formation, ~Passthrough(formation) + Passthrough(dissolution))
+  expect_equal(eval(quote(formation), envir = environment(est_hom_compare$formation)),
+               ~edges + nodematch("race", diff = TRUE))
+  expect_equal(eval(quote(dissolution), envir = environment(est_hom_compare$formation)),
+               ~offset(edges))
+
+  expect_equal(est_het_compare$formation, ~Passthrough(formation) + Passthrough(dissolution))
+  expect_equal(eval(quote(formation), envir = environment(est_het_compare$formation)),
+               ~edges + nodematch("race", diff = TRUE))
+  expect_equal(eval(quote(dissolution), envir = environment(est_het_compare$formation)),
+               ~offset(edges) + offset(nodematch("age", diff = TRUE)))
 })
 
 test_that("non-nested EDA", {
@@ -281,18 +288,38 @@ test_that("non-nested EDA", {
                 round(as.numeric(est_non_1_non_2$coef.form), 3)))
 
   expect_equal(est_nest_1$formation, ~edges + nodematch("race", diff = TRUE))
-  expect_equal(est_non_1$formation, ~edges + nodematch("race", diff = TRUE) +
-                 offset(edges) + offset(nodematch("race", diff = TRUE)))
-  expect_equal(est_non_2$formation, ~edges + nodematch("race", diff = TRUE) +
-                 offset(edges) + offset(nodematch("age", diff = TRUE)))
 
-  expect_equal(est_nest_1_non_2$formation, ~edges + nodematch("race", diff = TRUE) +
-                 offset(edges) + offset(nodematch("age", diff = TRUE)))
-  expect_equal(est_non_1_non_2$formation, ~edges + nodematch("race", diff = TRUE) +
-                 offset(edges) + offset(nodematch("age", diff = TRUE)))
+  expect_equal(est_non_1$formation, ~Passthrough(formation) + Passthrough(dissolution))
+  expect_equal(eval(quote(formation), envir = environment(est_non_1$formation)),
+               ~edges + nodematch("race", diff = TRUE))
+  expect_equal(eval(quote(dissolution), envir = environment(est_non_1$formation)),
+               ~offset(edges) + offset(nodematch("race", diff = TRUE)))
+
+  expect_equal(est_non_2$formation, ~Passthrough(formation) + Passthrough(dissolution))
+  expect_equal(eval(quote(formation), envir = environment(est_non_2$formation)),
+               ~edges + nodematch("race", diff = TRUE))
+  expect_equal(eval(quote(dissolution), envir = environment(est_non_2$formation)),
+               ~offset(edges) + offset(nodematch("age", diff = TRUE)))
+
+  expect_equal(est_nest_1_non_2$formation, ~Passthrough(formation) + Passthrough(dissolution))
+  expect_equal(eval(quote(formation), envir = environment(est_nest_1_non_2$formation)),
+               ~edges + nodematch("race", diff = TRUE))
+  expect_equal(eval(quote(dissolution), envir = environment(est_nest_1_non_2$formation)),
+               ~offset(edges) + offset(nodematch("age", diff = TRUE)))
+
+  expect_equal(est_non_1_non_2$formation, ~Passthrough(formation) + Passthrough(dissolution))
+  expect_equal(eval(quote(formation), envir = environment(est_non_1_non_2$formation)),
+               ~edges + nodematch("race", diff = TRUE))
+  expect_equal(eval(quote(dissolution), envir = environment(est_non_1_non_2$formation)),
+               ~offset(edges) + offset(nodematch("age", diff = TRUE)))
+
   expect_equal(est_non_2_nest_1$formation, ~edges + nodematch("race", diff = TRUE))
-  expect_equal(est_non_2_non_1$formation, ~edges + nodematch("race", diff = TRUE) +
-                 offset(edges) + offset(nodematch("race", diff = TRUE)))
+
+  expect_equal(est_non_2_non_1$formation, ~Passthrough(formation) + Passthrough(dissolution))
+  expect_equal(eval(quote(formation), envir = environment(est_non_2_non_1$formation)),
+               ~edges + nodematch("race", diff = TRUE))
+  expect_equal(eval(quote(dissolution), envir = environment(est_non_2_non_1$formation)),
+               ~offset(edges) + offset(nodematch("race", diff = TRUE)))
 })
 
 test_that("environment handling in non-nested EDA", {
@@ -318,17 +345,7 @@ test_that("environment handling in non-nested EDA", {
                      coef.diss = coef_diss,
                      nested.edapprox = FALSE)
 
-  expect_error(netdx_1 <- netdx(netest_1, nsims = 2, nsteps = 5, dynamic = TRUE, verbose = FALSE),
-               "object 'a' not found")
-
-  suppressWarnings(netest_2 <- netest(nw = nw,
-                                      formation = ~edges + nodematch(r, diff = TRUE),
-                                      target.stats = c(500, 50, 50, 90, 40, 60),
-                                      coef.diss = coef_diss,
-                                      nested.edapprox = FALSE,
-                                      from.new = "a"))
-
-  expect_error(netdx_2 <- netdx(netest_2, nsims = 2, nsteps = 5, dynamic = TRUE, verbose = FALSE), NA)
+  netdx_1 <- netdx(netest_1, nsims = 2, nsteps = 5, dynamic = TRUE, verbose = FALSE)
 
   make_formula_2 <- function() {
     x <- "race"
@@ -340,13 +357,193 @@ test_that("environment handling in non-nested EDA", {
 
   coef_diss_2 <- dissolution_coefs(ff_2, c(30, 40, 50, 25, 35, 55))
 
-  expect_error(netest_3 <- update_dissolution(netest_2, coef_diss_2,
+  expect_error(netest_2 <- update_dissolution(netest_1, coef_diss_2,
                                               nested.edapprox = TRUE),
                "Term options for one or more terms in dissolution model")
-  netest_3 <- update_dissolution(netest_2, coef_diss_2, nested.edapprox = FALSE)
-  expect_error(netdx_3 <- netdx(netest_3, nsims = 2, nsteps = 5, dynamic = TRUE, verbose = FALSE),
-               "object 'x' not found")
-  netest_4 <- update_dissolution(netest_2, coef_diss_2, nested.edapprox = FALSE,
-                                 from.new = "x")
-  expect_error(netdx_4 <- netdx(netest_4, nsims = 2, nsteps = 5, dynamic = TRUE, verbose = FALSE), NA)
+  netest_2 <- update_dissolution(netest_1, coef_diss_2, nested.edapprox = FALSE)
+  netdx_2 <- netdx(netest_2, nsims = 2, nsteps = 5, dynamic = TRUE, verbose = FALSE)
+})
+
+test_that("non-nested EDA produces expected statistic names, with or without trimming", {
+  for (trim in c(FALSE, TRUE)) {
+    nw <- network.initialize(10, directed = FALSE)
+    nw %v% "race" <- rep(1:3, length.out = 10)
+    nw %v% "age" <- rep(1:2, length.out = 10)
+
+    coef_diss <- dissolution_coefs(~offset(edges) + offset(nodematch("age", diff = TRUE)),
+                                   c(10, 25, 20))
+    est <- netest(nw,
+                  formation = ~edges + nodematch("race", diff = TRUE),
+                  target.stats = c(10, 3, 2, 1),
+                  coef.diss = coef_diss,
+                  nested.edapprox = FALSE)
+
+    if (trim == TRUE) {
+      est <- trim_netest(est)
+    }
+
+    formation_names <- c("edges", "nodematch.race.1", "nodematch.race.2",
+                         "nodematch.race.3", "offset(edges)", "offset(nodematch.age.1)",
+                         "offset(nodematch.age.2)")
+
+    dxs <- netdx(est, nsims = 100, dynamic = FALSE)
+    expect_equal(rownames(dxs$stats.table.formation), formation_names)
+
+    dxd <- netdx(est, nsims = 2, nsteps = 7, dynamic = TRUE)
+    expect_equal(rownames(dxd$stats.table.formation), formation_names)
+
+    param <- param.net(inf.prob = 0.3, act.rate = 0.5)
+    init <- init.net(i.num = 3)
+    control <- control.net(type = "SI", nsims = 1, nsteps = 5, verbose = FALSE)
+    sim <- netsim(est, param, init, control)
+    expect_equal(colnames(get_nwstats(sim, mode = "list")[[1]]), formation_names)
+  }
+})
+
+test_that("trimming non-nested EDA fails when it should", {
+  nw <- network.initialize(10, directed = FALSE)
+  nw %v% "race" <- rep(1:3, length.out = 10)
+  nw %v% "age" <- rep(1:2, length.out = 10)
+
+  coef_diss <- dissolution_coefs(~offset(edges) + offset(nodematch("age", diff = TRUE)),
+                                 c(10, 25, 20))
+
+  r <- "race"
+
+  est <- netest(nw,
+                formation = ~edges + nodematch(r, diff = TRUE),
+                target.stats = c(10, 3, 2, 1),
+                coef.diss = coef_diss,
+                nested.edapprox = FALSE)
+
+  est <- trim_netest(est)
+
+  expect_error(dxs <- netdx(est, nsims = 100, dynamic = FALSE), "object 'r' not found")
+  expect_error(dxd <- netdx(est, nsims = 2, nsteps = 7, dynamic = TRUE), "object 'r' not found")
+
+  param <- param.net(inf.prob = 0.3, act.rate = 0.5)
+  init <- init.net(i.num = 3)
+  control <- control.net(type = "SI", nsims = 1, nsteps = 5, verbose = FALSE)
+  expect_error(sim <- netsim(est, param, init, control), "object 'r' not found")
+
+  a <- "age"
+  coef_diss <- dissolution_coefs(~offset(edges) + offset(nodematch(a, diff = TRUE)),
+                                 c(10, 25, 20))
+
+  est <- netest(nw,
+                formation = ~edges + nodematch("race", diff = TRUE),
+                target.stats = c(10, 3, 2, 1),
+                coef.diss = coef_diss,
+                nested.edapprox = FALSE)
+
+  est <- trim_netest(est)
+
+  expect_error(dxs <- netdx(est, nsims = 100, dynamic = FALSE), "object 'a' not found")
+  expect_error(dxd <- netdx(est, nsims = 2, nsteps = 7, dynamic = TRUE), "object 'a' not found")
+
+  param <- param.net(inf.prob = 0.3, act.rate = 0.5)
+  init <- init.net(i.num = 3)
+  control <- control.net(type = "SI", nsims = 1, nsteps = 5, verbose = FALSE)
+  expect_error(sim <- netsim(est, param, init, control), "object 'a' not found")
+})
+
+test_that("non-nested EDA with substitutions", {
+  nw <- network_initialize(n = 100)
+  nw %v% "race" <- rep(letters[1:3], length.out = 100)
+  nw %v% "age" <- rep(1:2, length.out = 100)
+
+  make_form <- function() {
+    a <- "race"
+    ff <- ~edges + nodematch(a, diff = TRUE)
+    ff
+  }
+
+  make_diss_1 <- function() {
+    a <- "age"
+    ff <- ~offset(edges) + offset(nodematch(a, diff = TRUE))
+    ff
+  }
+
+  make_diss_2 <- function() {
+    a <- "race"
+    ff <- ~offset(edges) + offset(nodematch(a, diff = TRUE))
+    ff
+  }
+
+  make_diss_3 <- function() {
+    b <- "age"
+    ff <- ~offset(edges) + offset(nodematch(b, diff = TRUE))
+    ff
+  }
+
+  make_diss_4 <- function() {
+    b <- "race"
+    ff <- ~offset(edges) + offset(nodematch(b, diff = TRUE))
+    ff
+  }
+
+  formation_names_r <- c("edges", "nodematch.race.a", "nodematch.race.b",
+                         "nodematch.race.c")
+
+  formation_names_ra <- c("edges", "nodematch.race.a", "nodematch.race.b",
+                          "nodematch.race.c", "offset(edges)", "offset(nodematch.age.1)",
+                          "offset(nodematch.age.2)")
+
+  formation_names_rr <- c("edges", "nodematch.race.a", "nodematch.race.b",
+                          "nodematch.race.c", "offset(edges)", "offset(nodematch.race.a)",
+                          "offset(nodematch.race.b)", "offset(nodematch.race.c)")
+
+  diss_1 <- dissolution_coefs(make_diss_1(), c(10, 5, 7))
+  diss_2 <- dissolution_coefs(make_diss_2(), c(5, 4, 7, 8))
+  diss_3 <- dissolution_coefs(make_diss_3(), c(20, 50, 19))
+  diss_4 <- dissolution_coefs(make_diss_4(), c(3, 2, 9, 4))
+
+  formation <- make_form()
+
+  est_1 <- netest(nw = nw,
+                  formation = formation,
+                  target.stats = c(100, 10, 20, 30),
+                  coef.diss = diss_1,
+                  nested.edapprox = FALSE)
+
+  est_2 <- netest(nw = nw,
+                  formation = formation,
+                  target.stats = c(100, 10, 20, 30),
+                  coef.diss = diss_2)
+
+  run_sims <- function(est, expected_names) {
+    dxs <- netdx(est, nsims = 10, dynamic = FALSE)
+    dxd <- netdx(est, nsims = 2, nsteps = 5, dynamic = TRUE)
+    param <- param.net(inf.prob = 0.3, act.rate = 0.5)
+    init <- init.net(i.num = 3)
+    control <- control.net(type = "SI", nsims = 1, nsteps = 5, verbose = FALSE)
+    sim <- netsim(est, param, init, control)
+
+    expect_equal(rownames(dxs$stats.table.formation), expected_names)
+    expect_equal(rownames(dxd$stats.table.formation), expected_names)
+    expect_equal(colnames(get_nwstats(sim, mode = "list")[[1]]), expected_names)
+  }
+
+  run_sims(est_1, formation_names_ra)
+  run_sims(est_2, formation_names_r)
+
+  est_11 <- update_dissolution(est_1, diss_1, nested.edapprox = FALSE)
+  est_12 <- update_dissolution(est_1, diss_2, nested.edapprox = TRUE)
+  est_13 <- update_dissolution(est_1, diss_3, nested.edapprox = FALSE)
+  est_14 <- update_dissolution(est_1, diss_4, nested.edapprox = FALSE)
+
+  run_sims(est_11, formation_names_ra)
+  run_sims(est_12, formation_names_r)
+  run_sims(est_13, formation_names_ra)
+  run_sims(est_14, formation_names_rr)
+
+  est_21 <- update_dissolution(est_2, diss_1, nested.edapprox = FALSE)
+  est_22 <- update_dissolution(est_2, diss_2, nested.edapprox = TRUE)
+  est_23 <- update_dissolution(est_2, diss_3, nested.edapprox = FALSE)
+  est_24 <- update_dissolution(est_2, diss_4, nested.edapprox = FALSE)
+
+  run_sims(est_21, formation_names_ra)
+  run_sims(est_22, formation_names_r)
+  run_sims(est_23, formation_names_ra)
+  run_sims(est_24, formation_names_rr)
 })
