@@ -1,8 +1,8 @@
 context("Network models with formation offsets")
 
 test_that("netsim works with standard offset models", {
-  nw <- network.initialize(n = 50, directed = FALSE)
-  nw <- set.vertex.attribute(nw, "race", rbinom(50, 1, 0.5))
+  nw <- network_initialize(n = 50)
+  nw <- set_vertex_attribute(nw, "race", rbinom(50, 1, 0.5))
   est <- netest(nw, formation = ~edges + offset(nodematch("race")),
                 target.stats = 25, coef.form = -Inf,
                 coef.diss = dissolution_coefs(~offset(edges), 10, 0),
@@ -19,8 +19,8 @@ test_that("netsim works with standard offset models", {
 })
 
 test_that("netsim works with faux offset models", {
-  nw <- network.initialize(n = 50, directed = FALSE)
-  nw <- set.vertex.attribute(nw, "race", rbinom(50, 1, 0.5))
+  nw <- network_initialize(n = 50)
+  nw <- set_vertex_attribute(nw, "race", rbinom(50, 1, 0.5))
   est <- netest(nw, formation = ~edges + nodematch("race"),
                 target.stats = c(25, 0),
                 coef.diss = dissolution_coefs(~offset(edges), 10, 0),
