@@ -17,7 +17,7 @@ test_that("transmat class", {
   expect_true(is.transmat(tm))
   expect_false(is.transmat(list()))
   expect_true(inherits(tm, c("transmat", "data.frame")))
-  expect_equal(names(tm), c("at", "sus", "inf", "infDur", "transProb",
+  expect_equal(names(tm), c("at", "sus", "inf", "network", "infDur", "transProb",
                             "actRate", "finalProb"))
 })
 
